@@ -34,7 +34,6 @@ from .objet import Objet_avec_coordonnees, Ref, Argument, Objet, Arguments, \
                    contexte, Objet_avec_coordonnees_modifiables, issympy
 from .routines import angle_vectoriel, vect, carre_distance, produit_scalaire, \
                       distance
-from .constantes import FORMULE
 
 from .. import param
 
@@ -158,7 +157,7 @@ class Point_generique(Objet_avec_coordonnees):
             from .lignes import Segment
             with self.canvas.geler_affichage(actualiser = True):
                 M = Point("%s.x" %self.nom, 0, fixe = True)
-                M.label("${%s.x}$" %self.nom, mode=FORMULE)
+                M.label("${%s.x}$" %self.nom, mode='formule')
                 s = Segment(self, M, style = ":")
                 self.feuille.objets.add(M)
                 self.feuille.objets.add(s)
@@ -169,7 +168,7 @@ class Point_generique(Objet_avec_coordonnees):
             from .lignes import Segment
             with self.canvas.geler_affichage(actualiser = True):
                 M = Point(0, "%s.y" %self.nom, fixe = True)
-                M.label("${%s.y}$" %self.nom, mode=FORMULE)
+                M.label("${%s.y}$" %self.nom, mode='formule')
                 s = Segment(self, M, style = ":")
                 self.feuille.objets.add(M)
                 self.feuille.objets.add(s)
@@ -727,6 +726,13 @@ class Centre_gravite(Centre_polygone_generique):
 
     polygone = __polygone = Argument("Polygone_generique")
 
+    def __new__(cls, *args, **kw):
+        from .cercles import Cercle_generique
+        if len(args) == 1 and isinstance(args[0], Cercle_generique):
+            # Centre_gravite(cercle) -> Centre(cercle).
+            return Centre(*args, **kw)
+        return object.__new__(cls)
+
     def __init__(self, polygone, **styles):
         self.__polygone = polygone = Ref(polygone)
         Centre_polygone_generique.__init__(self, polygone, **styles)
@@ -818,6 +824,13 @@ class Centre(Point_generique):
 
     cercle = __cercle = Argument("Cercle_generique")
 
+    def __new__(cls, *args, **kw):
+        from .polygones import Polygone_generique
+        if len(args) == 1 and isinstance(args[0], Polygone_generique):
+            # Centre(polygone) -> Centre_gravite(polygone).
+            return Centre_gravite(*args, **kw)
+        return object.__new__(cls)
+
     def __init__(self, cercle, **styles):
         self.__cercle = cercle = Ref(cercle)
         Point_generique.__init__(self, **styles)
