@@ -424,17 +424,18 @@ def _remplacer_virgule(chaine):
 def preformatage_ensemble(chaine):
     u"""Formatage léger (qui reste humainement lisible)."""
     chaine = chaine.replace(" ", "")
-    chaine = _remplacer_virgule(chaine)
 
     # Traduction du LaTeX
     # On enlève le \ devant les commandes latex mathématiques usuelles
-    chaine = re.sub(r"\\(infty|e|pi|sin|cos|tan|ln|exp)", lambda m:m.group()[1:], chaine)
+    chaine = re.sub(r"\\(infty|e|pi|sin|cos|tan|ln|exp|R|oo)", lambda m:m.group()[1:], chaine)
     # conversion de \frac, \dfrac et \tfrac
     chaine = _convertir_latex_frac(chaine)
     # [1~;~3] -> [1;3] et [1\,;\,3] -> [1;3], etc.
     chaine = chaine.replace('~', '').replace(r'\,', '').replace(r'\;', '').replace(r'\:', '')
     # TODO: tests unitaires pour le LaTeX
 
+    chaine = _remplacer_virgule(chaine)
+
     chaine = chaine.replace('infty', 'oo').replace('inf', 'oo')
 
     chaine = re.sub(r"(?<![A-TV-Za-z_])(R\+\*|R\*\+)(?![A-TV-Za-z_{[(])", "]0;+oo[", chaine)
