@@ -5,6 +5,6 @@ NOMPROG = u"Géophar"
 NOMPROG2 = 'Geophar' # sans accent
 
 # Numéro de version (et date de sa sortie)
-version = '15.10.1'
-date_version = (2015, 10, 10)
-git = 'v15.10-1-g0f30172'
\ No newline at end of file
+version = '16.01'
+date_version = (2016, 1, 5)
+git = 'v15.10.2-4-g49ef9a4'
\ No newline at end of file
